from layers import FC_AConnect
from layers import Conv_AConnect
from scripts import MonteCarlo
from scripts import classify
from scripts import load_ds
from scripts import plotBox

__version__ = "1.3.4"
__author__ = 'Ricardo Vergel, Edward Silva, Luis Rueda and Elkim Roa'
def __init__():
	print("aconnect library")
	
	
